==> qtjambi-qml-debuginfo-windows-x64-6.5.3.jar: sources/QtJambiQml/QQmlImageProviderBase_shell.h <==
#ifndef QQMLIMAGEPROVIDERBASE_SHELL_H
#define QQMLIMAGEPROVIDERBASE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtQml/qqmlengine.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QQmlImageProviderBase_shell : public QQmlImageProviderBase, public QtJambiShellInterface
{
public:
    ~QQmlImageProviderBase_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QQmlImageProviderBase::Flags flags() const override;
    QQmlImageProviderBase::ImageType imageType() const override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QQmlImageProviderBase_access : public QQmlImageProviderBase
{
    jint __qt_flags(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_imageType(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QQMLIMAGEPROVIDERBASE_SHELL_H

==> qtjambi-qml-debuginfo-windows-x64-6.6.2.jar: sources/QtJambiQml/QQmlImageProviderBase_shell.h <==
#ifndef QQMLIMAGEPROVIDERBASE_SHELL_H
#define QQMLIMAGEPROVIDERBASE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtQml/qqmlengine.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtJambi/RegistryAPI>


class QQmlImageProviderBase_shell : public QQmlImageProviderBase, public QtJambiShellInterface
{
public:
    ~QQmlImageProviderBase_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QQmlImageProviderBase::Flags flags() const override;
    QQmlImageProviderBase::ImageType imageType() const override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QQmlImageProviderBase_access : public QQmlImageProviderBase
{
    jint __qt_flags_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_imageType_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QQMLIMAGEPROVIDERBASE_SHELL_H
